==> phoenix-starter-bpmn-0.1.0.18-20240511.071815-1-sources.jar: com/elitesland/cbpl/bpmn/registrar/BpmnInitialize.java <==
package com.elitesland.cbpl.bpmn.registrar;

import com.elitesland.cbpl.bpmn.domain.TaskStatus;
import com.elitesland.cbpl.bpmn.domain.VersionStatus;
import com.elitesland.cbpl.bpmn.service.TaskDefineService;
import com.elitesland.cbpl.bpmn.service.BpmnExecutor;
import com.elitesland.cbpl.bpmn.vo.param.TaskDefineQueryParamVO;
import com.elitesland.cbpl.bpmn.vo.resp.TaskDefineRespVO;
import com.elitesland.cbpl.tool.core.exceptions.ExceptionUtils;
import com.elitesland.cbpl.tool.tenant.TenantSpiUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.InitializingBean;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author eric.hao
 * @since 2024/05/08
 */
@Slf4j
@RequiredArgsConstructor
public class BpmnInitialize implements InitializingBean {

    @Resource
    private TaskDefineService taskDefineService;
    private final BpmnExecutor bpmnExecutor;

    public void afterPropertiesSet() {
        new Thread(() -> {
            try {
                TaskDefineQueryParamVO query = new TaskDefineQueryParamVO();
                query.setStatus(TaskStatus.ACTIVE.getCode());
                query.setVersionStatus(VersionStatus.EFFECTIVE.getCode());

                TenantSpiUtil.byTenants(() -> {
                    List<TaskDefineRespVO> taskDefine = taskDefineService.taskDefineByParam(query);
                    taskDefine.forEach(task -> bpmnExecutor.register(task.getTaskCode(), task.getVersion(), task.getTaskSpel()));
                });
            } catch (Exception e) {
                logger.error("[PHOENIX-BPMN] initialize failed: {}", ExceptionUtils.formatException(e));
            }
        }).start();
    }
}

==> phoenix-starter-bpmn-0.1.1.1-20240521.035918-1-sources.jar: com/elitesland/cbpl/bpmn/registrar/BpmnInitialize.java <==
package com.elitesland.cbpl.bpmn.registrar;

import com.elitesland.cbpl.bpmn.domain.TaskStatus;
import com.elitesland.cbpl.bpmn.domain.VersionStatus;
import com.elitesland.cbpl.bpmn.data.service.TaskDefineService;
import com.elitesland.cbpl.bpmn.data.service.BpmnExecutor;
import com.elitesland.cbpl.bpmn.data.vo.param.TaskDefineQueryParamVO;
import com.elitesland.cbpl.bpmn.data.vo.resp.TaskDefineRespVO;
import com.elitesland.cbpl.tool.core.exceptions.ExceptionUtils;
import com.elitesland.cbpl.tool.tenant.TenantSpiUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.InitializingBean;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author eric.hao
 * @since 2024/05/08
 */
@Slf4j
@RequiredArgsConstructor
public class BpmnInitialize implements InitializingBean {

    @Resource
    private TaskDefineService taskDefineService;
    private final BpmnExecutor bpmnExecutor;

    public void afterPropertiesSet() {
        new Thread(() -> {
            try {
                TaskDefineQueryParamVO query = new TaskDefineQueryParamVO();
                query.setStatus(TaskStatus.ACTIVE.getCode());
                query.setVersionStatus(VersionStatus.EFFECTIVE.getCode());

                TenantSpiUtil.byTenants(() -> {
                    List<TaskDefineRespVO> taskDefine = taskDefineService.taskDefineByParam(query);
                    taskDefine.forEach(task -> bpmnExecutor.register(task.getTaskCode(), task.getVersion(), task.getTaskSpel()));
                });
            } catch (Exception e) {
                logger.error("[PHOENIX-BPMN] initialize failed: {}", ExceptionUtils.formatException(e));
            }
        }).start();
    }
}
